@@ -212,12 +212,15 @@ w_schema_config = {
         Use(lambda x: f.get_open_func(x)(x, "rt")),
         error="mdmg_results should be readable",
     ),
-    Optional("filterBAM-stats-filter", default=default_filter_values_filterBAM,): And(
+    Optional(
+        "filterBAM-filter-conditions",
+        default=default_filter_values_filterBAM,
+    ): And(
         Use(
             lambda x: f.check_filter_conditions(
                 x,
                 default_filter_values_filterBAM,
-                filters=["breadth_exp_ratio", "coverage_mean"],
+                filters=fb_filters,
             )
         ),
         error="There's a problem with the filter. Please check the keys in the dict are valid and that all the values are >= 0",
@@ -231,14 +234,7 @@ w_schema_config = {
             lambda x: f.check_filter_conditions(
                 x,
                 default_filter_values_mdmg,
-                filters=[
-                    "D_max",
-                    "lambda_LR",
-                    "q",
-                    "phi",
-                    "Bayesian_D_max",
-                    "Bayesian_z",
-                ],
+                filters=mdmg_filters,
             )
         ),
         error="There's a problem with the filter. Please check the keys in the dict are valid and that all the values are >= 0",
@@ -451,3 +447,118 @@ seqSys_props = {
     "MSv3": {"se": 250, "pe": 250},
     "Other": {"se": None, "pe": None},
 }
+
+mdmg_filters = [
+    "N_reads",
+    "lambda_LR",
+    "D_max",
+    "mean_L",
+    "mean_GC",
+    "q",
+    "A",
+    "c",
+    "phi",
+    "rho_Ac",
+    "valid",
+    "asymmetry",
+    "std_L",
+    "std_GC",
+    "D_max_std",
+    "q_std",
+    "phi_std",
+    "A_std",
+    "c_std",
+    "lambda_LR_P",
+    "lambda_LR_z",
+    "forward_lambda_LR",
+    "forward_D_max",
+    "forward_D_max_std",
+    "forward_q",
+    "forward_q_std",
+    "forward_phi",
+    "forward_phi_std",
+    "forward_A",
+    "forward_A_std",
+    "forward_c",
+    "forward_c_std",
+    "forward_rho_Ac",
+    "forward_lambda_LR_P",
+    "forward_lambda_LR_z",
+    "forward_valid",
+    "reverse_lambda_LR",
+    "reverse_D_max",
+    "reverse_D_max_std",
+    "reverse_q",
+    "reverse_q_std",
+    "reverse_phi",
+    "reverse_phi_std",
+    "reverse_A",
+    "reverse_A_std",
+    "reverse_c",
+    "reverse_c_std",
+    "reverse_rho_Ac",
+    "reverse_lambda_LR_P",
+    "reverse_lambda_LR_z",
+    "reverse_valid",
+    "LR_All",
+    "LR_ForRev",
+    "LR_ForRev_All",
+    "chi2_all",
+    "chi2_forward",
+    "chi2_reverse",
+    "chi2_ForRev",
+    "N_x=1_forward",
+    "N_x=1_reverse",
+    "N_sum_total",
+    "N_sum_forward",
+    "N_sum_reverse",
+    "N_min",
+    "k_sum_total",
+    "k_sum_forward",
+    "k_sum_reverse",
+    "Bayesian_z",
+    "Bayesian_D_max",
+    "Bayesian_D_max_std",
+    "Bayesian_A",
+    "Bayesian_A_std",
+    "Bayesian_q",
+    "Bayesian_q_std",
+    "Bayesian_c",
+    "Bayesian_c_std",
+    "Bayesian_phi",
+    "Bayesian_phi_std",
+    "Bayesian_rho_Ac",
+]
+
+fb_filters = [
+    "n_reads",
+    "n_alns",
+    "read_length_mean",
+    "read_length_std",
+    "read_length_min",
+    "read_length_max",
+    "read_length_median",
+    "read_length_mode",
+    "gc_content",
+    "read_aligned_length",
+    "read_aln_score",
+    "mapping_quality",
+    "edit_distances",
+    "read_ani_mean",
+    "read_ani_std",
+    "reads_ani_median",
+    "bases_covered",
+    "max_covered_bases",
+    "mean_covered_bases",
+    "coverage_mean",
+    "coverage_covered_mean",
+    "reference_length",
+    "bam_reference_length",
+    "breadth",
+    "exp_breadth",
+    "breadth_exp_ratio",
+    "c_v",
+    "cov_evenness",
+    "tax_abund_read",
+    "tax_abund_aln",
+]
